@@ -3,14 +3,8 @@ import time
 
 import requests
 
-
-def release_strategy(toggle, _):
-    return toggle['value']
-
-
-strategy_maps = {
-    'release': release_strategy
-}
+from togglee.helpers.mappers import map_json_to_toggles
+from togglee.strategies.main import strategy_maps
 
 
 class Togglee:
@@ -19,14 +13,18 @@ class Togglee:
         self._refresh_rate = refresh_rate
         self._toggles = defaults
         self._thread = threading.Thread(target=self._scheduler_event)
+        self._thread.daemon = True
         self._thread.start()
 
     def is_enabled(self, prop: str, context=None):
         return self._get_value(prop, context) if self._toggles is not None and prop in self._toggles else False
 
     def _get_value(self, prop, context):
-        toggle = self._toggles[prop]
-        return strategy_maps[toggle['type']](toggle, context)
+        try:
+            toggle = self._toggles[prop]
+            return strategy_maps[toggle['type']](toggle, context)
+        except:
+            return False
 
     def _scheduler_event(self):
         self._refresh_toggles()
@@ -34,13 +32,9 @@ class Togglee:
             time.sleep(self._refresh_rate)
             self._refresh_toggles()
 
-    def _map_json_to_toggles(self, json_toggles):
-        mapped_toggles = {}
-        for toggle in json_toggles['toggles']:
-            mapped_toggles[toggle['name']] = toggle
-            mapped_toggles[toggle['name']].pop('name')
-        return mapped_toggles
-
     def _refresh_toggles(self):
-        response = requests.get(self._url)
-        self._toggles = self._map_json_to_toggles(response.json())
+        try:
+            response = requests.get(self._url)
+            self._toggles = map_json_to_toggles(response.json())
+        except:
+            pass
